#define ONCONNECT 0
#define ONRSPLOGIN 1
#define ONRTNCONTACTINFO 2
#define ONRSPREQUESTVERTIFICATECODE 3
#define ONEXPRIATIONDATE 4
#define ONAPIREADY 5
#define ONDISCONNECT 6
#define ONRSPCHANGEPASSWORD 7
#define ONRSPAUTHPASSWORD 8
#define ONRSPQRYTRADINGDATE 9
#define ONRSPSETRESERVEDINFO 10
#define ONRSPQRYACCOUNT 11
#define ONRSPQRYFUND 12
#define ONRTNFUND 13
#define ONRSPQRYEXCHANGE 14
#define ONRSPQRYCOMMODITY 15
#define ONRSPQRYCONTRACT 16
#define ONRTNCONTRACT 17
#define ONRSPORDERACTION 18
#define ONRTNORDER 19
#define ONRSPQRYORDER 20
#define ONRSPQRYORDERPROCESS 21
#define ONRSPQRYFILL 22
#define ONRTNFILL 23
#define ONRSPQRYPOSITION 24
#define ONRTNPOSITION 25
#define ONRSPQRYPOSITIONSUMMARY 26
#define ONRTNPOSITIONSUMMARY 27
#define ONRTNPOSITIONPROFIT 28
#define ONRSPQRYCURRENCY 29
#define ONRSPQRYTRADEMESSAGE 30
#define ONRTNTRADEMESSAGE 31
#define ONRSPQRYHISORDER 32
#define ONRSPQRYHISORDERPROCESS 33
#define ONRSPQRYHISMATCH 34
#define ONRSPQRYHISPOSITION 35
#define ONRSPQRYHISDELIVERY 36
#define ONRSPQRYACCOUNTCASHADJUST 37
#define ONRSPQRYBILL 38
#define ONRSPQRYACCOUNTFEERENT 39
#define ONRSPQRYACCOUNTMARGINRENT 40
#define ONRSPHKMARKETORDERINSERT 41
#define ONRSPHKMARKETORDERDELETE 42
#define ONHKMARKETQUOTENOTICE 43
#define ONRSPORDERLOCALREMOVE 44
#define ONRSPORDERLOCALINPUT 45
#define ONRSPORDERLOCALMODIFY 46
#define ONRSPORDERLOCALTRANSFER 47
#define ONRSPFILLLOCALINPUT 48
#define ONRSPFILLLOCALREMOVE 49
#define ONRSPQRYSPOTLOCK 50
#define ONRTNSPOTLOCK 51
#define ONRSPSUBMITUSERLOGININFO 52
#define ONRSPSPECIALORDERACTION 53
#define ONRTNSPECIALORDER 54
#define ONRSPQRYSPECIALORDER 55
#define ONRSPQRYCOMBINEPOSITION 56
#define ONRTNCOMBINEPOSITION 57
#define ONRSPQRYUSERTRUSTDEVICE 58
#define ONRSPADDUSERTRUSTDEVICE 59
#define ONRSPDELUSERTRUSTDEVICE 60
#define ONRTNADDUSERTRUSTDEVICE 61
#define ONRTNDELUSERTRUSTDEVICE 62
#define ONRSPQRYIPOINFO 63
#define ONRSPQRYIPOSTOCKQTY 64
#define ONRSPQRYACCOUNTIPO 65
#define ONRSPADDACCOUNTIPO 66
#define ONRSPCANCELACCOUNTIPO 67
#define ONRTNADDACCOUNTIPO 68
#define ONRTNCANCELACCOUNTIPO 69
#define ONRSPUNFREEZEVERIFICATE 70
