#define ONRSPLOGIN 0
#define ONAPIREADY 1
#define ONDISCONNECT 2
#define ONRSPQRYCOMMODITY 3
#define ONRSPQRYCONTRACT 4
#define ONRSPSUBSCRIBEQUOTE 5
#define ONRSPUNSUBSCRIBEQUOTE 6
#define ONRTNQUOTE 7
