void processRspLogin(Task *task);

void processAPIReady(Task *task);

void processDisconnect(Task *task);

void processRspQryCommodity(Task *task);

void processRspQryContract(Task *task);

void processRspSubscribeQuote(Task *task);

void processRspUnSubscribeQuote(Task *task);

void processRtnQuote(Task *task);

