.def("qryTradingDate", &TdApi::qryTradingDate)
.def("qryAccount", &TdApi::qryAccount)
.def("qryFund", &TdApi::qryFund)
.def("qryExchange", &TdApi::qryExchange)
.def("qryCommodity", &TdApi::qryCommodity)
.def("qryContract", &TdApi::qryContract)
.def("qryOrder", &TdApi::qryOrder)
.def("qryOrderProcess", &TdApi::qryOrderProcess)
.def("qryFill", &TdApi::qryFill)
.def("qryPosition", &TdApi::qryPosition)
.def("qryPositionSummary", &TdApi::qryPositionSummary)
.def("qryCurrency", &TdApi::qryCurrency)
.def("qryAccountCashAdjust", &TdApi::qryAccountCashAdjust)
.def("qryTradeMessage", &TdApi::qryTradeMessage)
.def("qryBill", &TdApi::qryBill)
.def("qryHisOrder", &TdApi::qryHisOrder)
.def("qryHisOrderProcess", &TdApi::qryHisOrderProcess)
.def("qryHisMatch", &TdApi::qryHisMatch)
.def("qryHisPosition", &TdApi::qryHisPosition)
.def("qryHisDelivery", &TdApi::qryHisDelivery)
.def("qryAccountFeeRent", &TdApi::qryAccountFeeRent)
.def("qryAccountMarginRent", &TdApi::qryAccountMarginRent)

.def("onConnect", &TdApi::onConnect)
.def("onRspLogin", &TdApi::onRspLogin)
.def("onRtnContactInfo", &TdApi::onRtnContactInfo)
.def("onRspRequestVertificateCode", &TdApi::onRspRequestVertificateCode)
.def("onExpriationDate", &TdApi::onExpriationDate)
.def("onAPIReady", &TdApi::onAPIReady)
.def("onDisconnect", &TdApi::onDisconnect)
.def("onRspChangePassword", &TdApi::onRspChangePassword)
.def("onRspAuthPassword", &TdApi::onRspAuthPassword)
.def("onRspQryTradingDate", &TdApi::onRspQryTradingDate)
.def("onRspSetReservedInfo", &TdApi::onRspSetReservedInfo)
.def("onRspQryAccount", &TdApi::onRspQryAccount)
.def("onRspQryFund", &TdApi::onRspQryFund)
.def("onRtnFund", &TdApi::onRtnFund)
.def("onRspQryExchange", &TdApi::onRspQryExchange)
.def("onRspQryCommodity", &TdApi::onRspQryCommodity)
.def("onRspQryContract", &TdApi::onRspQryContract)
.def("onRtnContract", &TdApi::onRtnContract)
.def("onRspOrderAction", &TdApi::onRspOrderAction)
.def("onRtnOrder", &TdApi::onRtnOrder)
.def("onRspQryOrder", &TdApi::onRspQryOrder)
.def("onRspQryOrderProcess", &TdApi::onRspQryOrderProcess)
.def("onRspQryFill", &TdApi::onRspQryFill)
.def("onRtnFill", &TdApi::onRtnFill)
.def("onRspQryPosition", &TdApi::onRspQryPosition)
.def("onRtnPosition", &TdApi::onRtnPosition)
.def("onRspQryPositionSummary", &TdApi::onRspQryPositionSummary)
.def("onRtnPositionSummary", &TdApi::onRtnPositionSummary)
.def("onRtnPositionProfit", &TdApi::onRtnPositionProfit)
.def("onRspQryCurrency", &TdApi::onRspQryCurrency)
.def("onRspQryTradeMessage", &TdApi::onRspQryTradeMessage)
.def("onRtnTradeMessage", &TdApi::onRtnTradeMessage)
.def("onRspQryHisOrder", &TdApi::onRspQryHisOrder)
.def("onRspQryHisOrderProcess", &TdApi::onRspQryHisOrderProcess)
.def("onRspQryHisMatch", &TdApi::onRspQryHisMatch)
.def("onRspQryHisPosition", &TdApi::onRspQryHisPosition)
.def("onRspQryHisDelivery", &TdApi::onRspQryHisDelivery)
.def("onRspQryAccountCashAdjust", &TdApi::onRspQryAccountCashAdjust)
.def("onRspQryBill", &TdApi::onRspQryBill)
.def("onRspQryAccountFeeRent", &TdApi::onRspQryAccountFeeRent)
.def("onRspQryAccountMarginRent", &TdApi::onRspQryAccountMarginRent)
.def("onRspHKMarketOrderInsert", &TdApi::onRspHKMarketOrderInsert)
.def("onRspHKMarketOrderDelete", &TdApi::onRspHKMarketOrderDelete)
.def("onHKMarketQuoteNotice", &TdApi::onHKMarketQuoteNotice)
.def("onRspOrderLocalRemove", &TdApi::onRspOrderLocalRemove)
.def("onRspOrderLocalInput", &TdApi::onRspOrderLocalInput)
.def("onRspOrderLocalModify", &TdApi::onRspOrderLocalModify)
.def("onRspOrderLocalTransfer", &TdApi::onRspOrderLocalTransfer)
.def("onRspFillLocalInput", &TdApi::onRspFillLocalInput)
.def("onRspFillLocalRemove", &TdApi::onRspFillLocalRemove)
.def("onRspQrySpotLock", &TdApi::onRspQrySpotLock)
.def("onRtnSpotLock", &TdApi::onRtnSpotLock)
.def("onRspSubmitUserLoginInfo", &TdApi::onRspSubmitUserLoginInfo)
.def("onRspSpecialOrderAction", &TdApi::onRspSpecialOrderAction)
.def("onRtnSpecialOrder", &TdApi::onRtnSpecialOrder)
.def("onRspQrySpecialOrder", &TdApi::onRspQrySpecialOrder)
.def("onRspQryCombinePosition", &TdApi::onRspQryCombinePosition)
.def("onRtnCombinePosition", &TdApi::onRtnCombinePosition)
.def("onRspQryUserTrustDevice", &TdApi::onRspQryUserTrustDevice)
.def("onRspAddUserTrustDevice", &TdApi::onRspAddUserTrustDevice)
.def("onRspDelUserTrustDevice", &TdApi::onRspDelUserTrustDevice)
.def("onRtnAddUserTrustDevice", &TdApi::onRtnAddUserTrustDevice)
.def("onRtnDelUserTrustDevice", &TdApi::onRtnDelUserTrustDevice)
.def("onRspQryIPOInfo", &TdApi::onRspQryIPOInfo)
.def("onRspQryIPOStockQty", &TdApi::onRspQryIPOStockQty)
.def("onRspQryAccountIPO", &TdApi::onRspQryAccountIPO)
.def("onRspAddAccountIPO", &TdApi::onRspAddAccountIPO)
.def("onRspCancelAccountIPO", &TdApi::onRspCancelAccountIPO)
.def("onRtnAddAccountIPO", &TdApi::onRtnAddAccountIPO)
.def("onRtnCancelAccountIPO", &TdApi::onRtnCancelAccountIPO)
.def("onRspUnFreezeVerificate", &TdApi::onRspUnFreezeVerificate)
;
