void processConnect(Task *task);

void processRspLogin(Task *task);

void processRtnContactInfo(Task *task);

void processRspRequestVertificateCode(Task *task);

void processExpriationDate(Task *task);

void processAPIReady(Task *task);

void processDisconnect(Task *task);

void processRspChangePassword(Task *task);

void processRspAuthPassword(Task *task);

void processRspQryTradingDate(Task *task);

void processRspSetReservedInfo(Task *task);

void processRspQryAccount(Task *task);

void processRspQryFund(Task *task);

void processRtnFund(Task *task);

void processRspQryExchange(Task *task);

void processRspQryCommodity(Task *task);

void processRspQryContract(Task *task);

void processRtnContract(Task *task);

void processRspOrderAction(Task *task);

void processRtnOrder(Task *task);

void processRspQryOrder(Task *task);

void processRspQryOrderProcess(Task *task);

void processRspQryFill(Task *task);

void processRtnFill(Task *task);

void processRspQryPosition(Task *task);

void processRtnPosition(Task *task);

void processRspQryPositionSummary(Task *task);

void processRtnPositionSummary(Task *task);

void processRtnPositionProfit(Task *task);

void processRspQryCurrency(Task *task);

void processRspQryTradeMessage(Task *task);

void processRtnTradeMessage(Task *task);

void processRspQryHisOrder(Task *task);

void processRspQryHisOrderProcess(Task *task);

void processRspQryHisMatch(Task *task);

void processRspQryHisPosition(Task *task);

void processRspQryHisDelivery(Task *task);

void processRspQryAccountCashAdjust(Task *task);

void processRspQryBill(Task *task);

void processRspQryAccountFeeRent(Task *task);

void processRspQryAccountMarginRent(Task *task);

void processRspHKMarketOrderInsert(Task *task);

void processRspHKMarketOrderDelete(Task *task);

void processHKMarketQuoteNotice(Task *task);

void processRspOrderLocalRemove(Task *task);

void processRspOrderLocalInput(Task *task);

void processRspOrderLocalModify(Task *task);

void processRspOrderLocalTransfer(Task *task);

void processRspFillLocalInput(Task *task);

void processRspFillLocalRemove(Task *task);

void processRspQrySpotLock(Task *task);

void processRtnSpotLock(Task *task);

void processRspSubmitUserLoginInfo(Task *task);

void processRspSpecialOrderAction(Task *task);

void processRtnSpecialOrder(Task *task);

void processRspQrySpecialOrder(Task *task);

void processRspQryCombinePosition(Task *task);

void processRtnCombinePosition(Task *task);

void processRspQryUserTrustDevice(Task *task);

void processRspAddUserTrustDevice(Task *task);

void processRspDelUserTrustDevice(Task *task);

void processRtnAddUserTrustDevice(Task *task);

void processRtnDelUserTrustDevice(Task *task);

void processRspQryIPOInfo(Task *task);

void processRspQryIPOStockQty(Task *task);

void processRspQryAccountIPO(Task *task);

void processRspAddAccountIPO(Task *task);

void processRspCancelAccountIPO(Task *task);

void processRtnAddAccountIPO(Task *task);

void processRtnCancelAccountIPO(Task *task);

void processRspUnFreezeVerificate(Task *task);

