APIYNFLAG_YES = "Y"
APIYNFLAG_NO = "N"
APIPASSWORD_TRADE = "T"
APIPASSWORD_PHONE = "P"
APILOGLEVEL_NONE = "N"
APILOGLEVEL_ERROR = "E"
APILOGLEVEL_WARNING = "W"
APILOGLEVEL_DEBUG = "D"
TAPI_OPTION_TYPE_AMERICAN = "A"
TAPI_OPTION_TYPE_AMERICAN2 = "B"
TAPI_OPTION_TYPE_EUROPEAN = "E"
TAPI_OPTION_TYPE_EUROPEAN2 = "F"
TAPI_COMMODITY_TYPE_NONE = "N"
TAPI_COMMODITY_TYPE_FUTURES = "F"
TAPI_COMMODITY_TYPE_OPTION = "O"
TAPI_COMMODITY_TYPE_SPREAD_MONTH = "S"
TAPI_COMMODITY_TYPE_SPREAD_COMMODITY = "M"
TAPI_COMMODITY_TYPE_BUL = "U"
TAPI_COMMODITY_TYPE_BER = "E"
TAPI_COMMODITY_TYPE_STD = "D"
TAPI_COMMODITY_TYPE_STG = "G"
TAPI_COMMODITY_TYPE_PRT = "R"
TAPI_COMMODITY_TYPE_DIRECTFOREX = "X"
TAPI_COMMODITY_TYPE_INDIRECTFOREX = "I"
TAPI_COMMODITY_TYPE_CROSSFOREX = "C"
TAPI_COMMODITY_TYPE_INDEX = "Z"
TAPI_COMMODITY_TYPE_STOCK = "T"
TAPI_COMMODITY_TYPE_TAS = "B"
TAPI_COMMODITY_TYPE_DERIVATIVE = "0"
TAPI_COMMODITY_TYPE_BULLBEAR = "1"
TAPI_COMMODITY_TYPE_INLINE = "2"
TAPI_COMMODITY_TYPE_DBET = "3"
TAPI_COMMODITY_TYPE_FUND = "4"
TAPI_COMMODITY_TYPE_MULTI_LEG = "5"
TAPI_CALLPUT_FLAG_CALL = "C"
TAPI_CALLPUT_FLAG_PUT = "P"
TAPI_CALLPUT_FLAG_NONE = "N"

TAPI_ACCOUNT_TYPE_PERSON = "P"
TAPI_ACCOUNT_TYPE_ORGANIZATION = "O"
TAPI_ACCOUNT_TYPE_AGENT = "A"
TAPI_ACCOUNT_TYPE_MARGIN = "M"
TAPI_ACCOUNT_TYPE_HOUSE = "H"
TAPI_ACCOUNT_TYPE_STOCK = "S"
TAPI_USERTYPE_CLIENT = 10000
TAPI_USERTYPE_BROKER = 20000
TAPI_USERTYPE_TRADER = 30000
TAPI_USERTYPE_RISK = 40000
TAPI_USERTYPE_MANAGER = 50000
TAPI_USERTYPE_QUOTE = 60000
TAPI_ACCOUNT_STATE_NORMAL = "N"
TAPI_ACCOUNT_STATE_CANCEL = "C"
TAPI_ACCOUNT_STATE_SLEEP = "S"
TAPI_ACCOUNT_STATE_FROZEN = "F"
TAPI_ACCOUNT_TRADING_RIGHT_NORMAL = "0"
TAPI_ACCOUNT_TRADING_RIGHT_NOTRADE = "1"
TAPI_ACCOUNT_TRADING_RIGHT_CLOSE = "2"
TAPI_ORDER_TYPE_MARKET = "1"
TAPI_ORDER_TYPE_LIMIT = "2"
TAPI_ORDER_TYPE_STOP_MARKET = "3"
TAPI_ORDER_TYPE_STOP_LIMIT = "4"
TAPI_ORDER_TYPE_OPT_EXEC = "5"
TAPI_ORDER_TYPE_OPT_ABANDON = "6"
TAPI_ORDER_TYPE_REQQUOT = "7"
TAPI_ORDER_TYPE_RSPQUOT = "8"
TAPI_ORDER_TYPE_ICEBERG = "9"
TAPI_ORDER_TYPE_GHOST = "A"
TAPI_ORDER_TYPE_HKEX_AUCTION = "B"
TAPI_ORDER_TYPE_SWAP = "C"
TAPI_ORDER_TYPE_LOCK = "D"
TAPI_ORDER_TYPE_UNLOCK = "E"
TAPI_ORDER_TYPE_ENHANCE = "F"
TAPI_ORDER_TYPE_SPECIAL = "G"
TAPI_ORDER_TYPE_LIMITAUCTION = "H"
TAPI_ORDER_SOURCE_SELF_ETRADER = "1"
TAPI_ORDER_SOURCE_PROXY_ETRADER = "2"
TAPI_ORDER_SOURCE_JTRADER = "3"
TAPI_ORDER_SOURCE_MANUAL = "4"
TAPI_ORDER_SOURCE_CARRY = "5"
TAPI_ORDER_SOURCE_PROGRAM = "6"
TAPI_ORDER_SOURCE_DELIVERY = "7"
TAPI_ORDER_SOURCE_ABANDON = "8"
TAPI_ORDER_SOURCE_CHANNEL = "9"
TAPI_ORDER_SOURCE_TEMPORARY = "J"
TAPI_ORDER_SOURCE_PROGRAMMANUAL = "K"
TAPI_ORDER_TIMEINFORCE_GFD = "0"
TAPI_ORDER_TIMEINFORCE_GTC = "1"
TAPI_ORDER_TIMEINFORCE_GTD = "2"
TAPI_ORDER_TIMEINFORCE_FAK = "3"
TAPI_ORDER_TIMEINFORCE_FOK = "4"
TAPI_SIDE_NONE = "N"
TAPI_SIDE_BUY = "B"
TAPI_SIDE_SELL = "S"
TAPI_PositionEffect_NONE = "N"
TAPI_PositionEffect_OPEN = "O"
TAPI_PositionEffect_COVER = "C"
TAPI_PositionEffect_COVER_TODAY = "T"
TAPI_HEDGEFLAG_NONE = "N"
TAPI_HEDGEFLAG_T = "T"
TAPI_HEDGEFLAG_B = "B"
TAPI_HEDGEFLAG_R = "R"
TAPI_ORDER_STATE_SUBMIT = "0"
TAPI_ORDER_STATE_ACCEPT = "1"
TAPI_ORDER_STATE_TRIGGERING = "2"
TAPI_ORDER_STATE_EXCTRIGGERING = "3"
TAPI_ORDER_STATE_QUEUED = "4"
TAPI_ORDER_STATE_PARTFINISHED = "5"
TAPI_ORDER_STATE_FINISHED = "6"
TAPI_ORDER_STATE_CANCELING = "7"
TAPI_ORDER_STATE_MODIFYING = "8"
TAPI_ORDER_STATE_CANCELED = "9"
TAPI_ORDER_STATE_LEFTDELETED = "A"
TAPI_ORDER_STATE_FAIL = "B"
TAPI_ORDER_STATE_DELETED = "C"
TAPI_ORDER_STATE_SUPPENDED = "D"
TAPI_ORDER_STATE_DELETEDFOREXPIRE = "E"
TAPI_ORDER_STATE_EFFECT = "F"
TAPI_ORDER_STATE_APPLY = "G"
TAPI_CALULATE_MODE_COMBINE = "0"
TAPI_CALCULATE_MODE_PERCENTAGE = "1"
TAPI_CALCULATE_MODE_QUOTA = "2"
TAPI_CALCULATE_MODE_CHAPERCENTAGE = "3"
TAPI_CALCULATE_MODE_CHAQUOTA = "4"
TAPI_CALCULATE_MODE_DISCOUNT = "5"
TAPI_MATCH_SOURCE_ALL = "0"
TAPI_MATCH_SOURCE_SELF_ETRADER = "1"
TAPI_MATCH_SOURCE_PROXY_ETRADER = "2"
TAPI_MATCH_SOURCE_JTRADER = "3"
TAPI_MATCH_SOURCE_MANUAL = "4"
TAPI_MATCH_SOURCE_CARRY = "5"
TAPI_MATCH_SOURCE_PROGRAM = "6"
TAPI_MATCH_SOURCE_DELIVERY = "7"
TAPI_MATCH_SOURCE_ABANDON = "8"
TAPI_MATCH_SOURCE_CHANNEL = "9"
TAPI_MATCH_SOURCE_BLOOMBERG = "B"
TAPI_MATCH_SOURCE_AUTOPHONE = "A"
TAPI_MATCH_SOURCE_GIVEUP = "C"
TAPI_MATCH_SOURCE_EXERCISE = "E"
TAPI_MATCH_SOURCE_TAKEUP = "D"
TAPI_MATCH_SOURCE_INPUT_DELETE = "#"
TAPI_MATCH_SOURCE_ERRORADJUST = "F"
TAPI_MATCH_SOURCE_BROKER_ETRADER = "G"
TAPI_MATCH_SOURCE_TEMPORARY = "J"
TAPI_MATCH_SOURCE_PROGRAMMANUAL = "K"
TAPI_CLOSE_MODE_NONE = "N"
TAPI_CLOSE_MODE_UNFINISHED = "U"
TAPI_CLOSE_MODE_OPENCOVER = "C"
TAPI_CLOSE_MODE_CLOSETODAY = "T"
TAPI_FUTURES_ALG_ZHUBI = "Y"
TAPI_FUTURES_ALG_DINGSHI = "N"
TAPI_OPTION_ALG_FUTURES = "1"
TAPI_OPTION_ALG_OPTION = "2"
TAPI_LWFlag_L = "L"
TAPI_LWFlag_W = "W"
TAPI_CASHINOUT_MODE_FEEADJUST = "0"
TAPI_CASHINOUT_MODE_YKADJUST = "1"
TAPI_CASHINOUT_MODE_PLEDGE = "2"
TAPI_CASHINOUT_MODE_INTERESTREVENUE = "3"
TAPI_CASHINOUT_MODE_COLLECTIONCOST = "4"
TAPI_CASHINOUT_MODE_OTHER = "5"
TAPI_CASHINOUT_MODE_COMPANY = "6"
TAPI_DEPOSITCALCULATE_MODE_FEN = "1"
TAPI_DEPOSITCALCULATE_MODE_SUO = "2"
TAPI_CMB_DIRECT_FIRST = "1"
TAPI_CMB_DIRECT_SECOND = "2"
TAPI_DELIVERY_MODE_GOODS = "G"
TAPI_DELIVERY_MODE_CASH = "C"
TAPI_DELIVERY_MODE_EXECUTE = "E"
TAPI_DELIVERY_MODE_ABANDON = "A"
TAPI_DELIVERY_MODE_HKF = "H"
TAPI_CONTRACT_TYPE_TRADEQUOTE = "1"
TAPI_CONTRACT_TYPE_QUOTE = "2"
TAPI_TACTICS_TYPE_NONE = "N"
TAPI_TACTICS_TYPE_READY = "M"
TAPI_TACTICS_TYPE_ATUO = "A"
TAPI_TACTICS_TYPE_CONDITION = "C"
APIORDER_INSERT = "1"
APIORDER_MODIFY = "2"
APIORDER_DELETE = "3"
APIORDER_SUSPEND = "4"
APIORDER_ACTIVATE = "5"
APIORDER_SYSTEM_DELETE = "6"
TAPI_TRIGGER_CONDITION_NONE = "N"
TAPI_TRIGGER_CONDITION_GREAT = "G"
TAPI_TRIGGER_CONDITION_LITTLE = "L"
TAPI_TRIGGER_PRICE_NONE = "N"
TAPI_TRIGGER_PRICE_BUY = "B"
TAPI_TRIGGER_PRICE_SELL = "S"
TAPI_TRIGGER_PRICE_LAST = "L"
TAPI_TRADE_STATE_BID = "1"
TAPI_TRADE_STATE_MATCH = "2"
TAPI_TRADE_STATE_CONTINUOUS = "3"
TAPI_TRADE_STATE_PAUSED = "4"
TAPI_TRADE_STATE_CLOSE = "5"
TAPI_TRADE_STATE_DEALLAST = "6"
TAPI_TRADE_STATE_GWDISCONNECT = "0"
TAPI_TRADE_STATE_UNKNOWN = "N"
TAPI_TRADE_STATE_INITIALIZE = "I"
TAPI_TRADE_STATE_READY = "R"
TAPI_NOTICE_IGNORE_NONE = 0x00000000
TAPI_NOTICE_IGNORE_ALL = 0xFFFFFFFF
TAPI_NOTICE_IGNORE_FUND = 0x00000001
TAPI_NOTICE_IGNORE_ORDER = 0x00000002
TAPI_NOTICE_IGNORE_FILL = 0x00000004
TAPI_NOTICE_IGNORE_POSITION = 0x00000008
TAPI_NOTICE_IGNORE_CLOSE = 0x00000010
TAPI_NOTICE_IGNORE_POSITIONPROFIT = 0x00000020
TAPI_ORDER_QRY_TYPE_ALL = "A"
TAPI_ORDER_QRY_TYPE_UNENDED = "U"
TAPI_LOGINTYPE_NORMAL = "N"
TAPI_LOGINTYPE_TEMPORARY = "T"
TAPI_MSG_RECEIVER_ACCOUNTNO = "1"
TAPI_MSG_RECEIVER_ACCOUNTGROUPNO = "2"
TAPI_MSG_RECEIVER_ATTRIBUTE = "3"
TAPI_MSG_RECEIVER_USERNO = "4"
TAPI_MSG_LEVEL_NORMAL = "1"
TAPI_MSG_LEVEL_IMPORTANT = "2"
TAPI_MSG_LEVEL_IMERGENCY = "3"
TAPI_Msg_TYPE_MANAGER = "1"
TAPI_Msg_TYPE_RISKCONTROL = "2"
TAPI_BILL_DATE = "D"
TAPI_BILL_MONTH = "M"
TAPI_BILL_FILE_TXT = "T"
TAPI_BILL_FILE_PDF = "F"
SettleFlag_AutoSettle = "0"
SettleFlagh_Manual = "2"
TAPI_ABNORMAL_NORMAL = "0"
TAPI_ABNORMAL_GATHERINFO_NONE = "1"
TAPI_ABNORMAL_AUTHKEYVERSION = "2"
TAPI_ABNORMAL_GATHERINFO_WRONG = "3"
TAPI_STRATEGY_C_BULL = "CNSJC"
TAPI_STRATEGY_P_BEAR = "PXSJC"
TAPI_STRATEGY_P_BULL = "PNSJC"
TAPI_STRATEGY_C_BEAR = "CXSJC"
TAPI_STRATEGY_S_STRADDLE = "KS"
TAPI_STRATEGY_S_STRANGLE = "KKS"
TAPI_STRATEGY_ZBD = "ZBD"
TAPI_STRATEGY_ZXJ = "ZXJ"
TAPI_STRATEGY_COMBINE = "1"
TAPI_STRATEGY_SPLIT = "2"
TAPI_SPOT_LOCK = "3"
TAPI_SPOT_UNLOCK = "4"
TAPI_OPTION_EXERCISE = "5"
TAPI_OPTION_EXERCISE_COMBINE = "6"
TAPI_APPLYTYPE_CASH = "1"
TAPI_APPLYTYPE_LOAN = "2"
TAPI_APPLYSTAUTS_APPLY = "0"
TAPI_APPLYSTAUTS_FAIL = "1"
TAPI_APPLYSTAUTS_WAIT = "2"
TAPI_APPLYSTAUTS_CANCEL = "3"
TAPI_APPLYSTAUTS_DONE = "4"
TAPI_APPLYSTAUTS_NOLUCKY = "5"
TAPI_APPLYSTAUTS_LUCKY = "6"
TAPI_APPLYSTAUTS_WAITCANCEL = "7"
TAPI_CERTIFICATE_MAINLANDID = "1"
TAPI_CERTIFICATE_MILITARYCARD = "2"
TAPI_CERTIFICATE_POLICECARD = "3"
TAPI_CERTIFICATE_SOLDIERID = "4"
TAPI_CERTIFICATE_ACCOUNTBOOK = "5"
TAPI_CERTIFICATE_PASSPORT_CHINESE = "6"
TAPI_CERTIFICATE_MTPS = "7"
TAPI_CERTIFICATE_HOMERETURN = "8"
TAPI_CERTIFICATE_BUSINESSLICENSE = "9"
TAPI_CERTIFICATE_ENTERPRISELEGALPESON = "A"
TAPI_CERTIFICATE_OTHERID = "B"
TAPI_CERTIFICATE_PASSPORT_OTHER = "C"
TAPI_CERTIFICATE_OTHER = "x"
TAPI_CERTIFICATE_BUSINESSREGISTRATION = "R"

TAPIERROR_LOGIN = 10001
TAPIERROR_LOGIN_USER = 10002
TAPIERROR_LOGIN_DDA = 10003
TAPIERROR_LOGIN_LICENSE = 10004
TAPIERROR_LOGIN_MODULE = 10005
TAPIERROR_LOGIN_FORCE = 10006
TAPIERROR_LOGIN_STATE = 10007
TAPIERROR_LOGIN_PASS = 10008
TAPIERROR_LOGIN_RIGHT = 10009
TAPIERROR_LOGIN_COUNT = 10010
TAPIERROR_LOGIN_NOTIN_SERVERFLAGUSRES = 10011
TAPIERROR_LOGIN_FREEZE = 10012
TAPIERROR_LOGIN_TOFREEZE = 10013
TAPIERROR_LOGIN_ACCOUNTSTATE = 10014
TAPIERROR_LOGIN_SECCERTIFI = 10015
TAPIERROR_LOGIN_NOSECONDSET = 10016
TAPIERROR_LOGIN_NOTURSTHOST = 10017
TAPIERROR_LOGIN_NOTINTRADECENTER = 10019
TAPIERROR_LOGIN_INCONSISTENT = 10020
TAPIERROR_LOGIN_NOCENTERFRONTADDRESS = 10021
TAPIERROR_LOGIN_PROHIBITACCOUNTTYPE = 10022
TAPIERROR_LOGIN_GATHERINFO_DIRECT = 10023
TAPIERROR_LOGIN_GATHERINFO_RELAY = 10024
TAPIERROR_LOGIN_RESET_PASSWORD = 10025
TAPIERROR_LOGIN_RESET_PASSWORD_EXCEEDED = 10026
TAPIERROR_LOGIN_OPERATOR_UNALLOWED_RESET = 10027
TAPIERROR_LOGIN_RESET_PASSWORD_FROZEN = 10028
TAPIERROR_LOGIN_VERIFYIDENTITY_FAILED = 10029
TAPIERROR_LOGIN_VERIFYIDENTITY_EXCEED = 10030
TAPIERROR_LOGIN_LICENSE_EXPIRED = 10031
TAPIERROR_LOGIN_PROHIBITRESETPASSWORD = 10032
TAPIERROR_LOGIN_UNFREEZE = 10033
TAPIERROR_LOGIN_UNFREEZE_EXCEEDED = 10034
TAPIERROR_LOGIN_PROHIBIT_UNFREEZE = 10035
TAPIERROR_LOGIN_NONEED_UNFREEZE = 10036
TAPIERROR_SECONDCERTIFICATION_FAIL = 14001
TAPIERROR_SECONDCERTIFICATION_TIMEOVER = 14002
TAPIERROR_SECONDCERTIFICATION_RELOGIN = 14003
TAPIERROR_SECONDCERTIFICATION_FREEZE = 14004
TAPIERROR_DATA_REPEAT = 1062
TAPIERROR_CONN_DATABASE = 11000
TAPIERROR_OPER_DATABASE = 11001
TAPIERROR_NEED_ONETOONE = 11002
TAPIERROR_EXIST_RELATEINFO = 11003
TAPIERROR_EXIST_RELATEINFOOFGROUP = 11004
TAPIERROR_CHECK_FAILED = 11006
TAPIERROR_EXIST_OUTSIDECOMMODITYNO = 11007
TAPIERROR_NOTEXIST_BILL = 11008
TAPIERROR_LOGIN_PROHIBITADDACCOUNTTYPE = 11009
TAPIERROR_ACCOUNTINFO_NOTEXPTY = 11010
TAPIERROR_ACCOUNTINFO_SuperiorNOTEMPTY = 11011
TAPIERROR_USERTRUSTDEVICE_ADDLIMITE = 11012
TAPIERROR_UPPERACCOUNTMAPPING_NOTALLOW = 11013
TAPIERROR_USERPASSWORD_MOD_SOURCE = 12001
TAPIERROR_USERPASSWORD_MOD_SAME = 12002
TAPIERROR_USERPASSWORD_MOD_COMPLEXITY = 12003
TAPIERROR_CURRENCY_ONLY_ONEBASE = 13001
TAPIERROR_CURRENCY_ONLY_USDHKD = 13002
TAPIERROR_GATHERINFO_NO_AUTHKEY = 17001
TAPIERROR_GATHERINFO_AUTH_FAILED = 17002
TAPIERROR_ORDERINSERT_ACCOUNT = 60001
TAPIERROR_ORDERINSERT_ACCOUNT_STATE = 60002
TAPIERROR_ORDERINSERT_TRADECENT_ERROR = 60003
TAPIERROR_ORDERINT_MAINACCOUNT_ERROR = 60004
TAPIERROR_ORDERINT_MAINACCINFO_ERROR = 60005
TAPIERROR_ORDERINT_NO_OPTMARKET_ERROR = 60006
TAPIERROR_ORDERINT_UN_SUPPORT_ERROR = 60007
TAPIERROR_ORDERINSERT_CONTRACT = 60011
TAPIERROR_ORDERINSERT_LME_NOTREADY = 60012
TAPIERROR_ORDERINSERT_ERROR_ORDER_TYPE = 60013
TAPIERROR_ORDERINSERT_READY_TYPE_ERROR = 60014
TAPIERROR_ORDERINSERT_ORDER_TYPE_ERROR = 60015
TAPIERROR_ORDERINSERT_SUBCONTRACT = 60016
TAPIERROR_ORDERINSERT_SPOTBUYQTY = 60017
TAPIERROR_ORDERINSERT_RESERVE_PUT = 60018
TAPIERROR_ORDERINSERT_RESERVE_B_OPEN = 60019
TAPIERROR_ORDERINSERT_RESERVE_S_COVER = 60020
TAPIERROR_ORDER_NOTRADE_ACCOUNT = 60021
TAPIERROR_ORDER_NOTRADE_COM_GROUP = 60022
TAPIERROR_ORDER_NOTRADE_ACC_CONTRACT = 60023
TAPIERROR_ORDER_NOTRADE_SYSTEM = 60024
TAPIERROR_ORDER_CLOSE_ACCOUNT = 60025
TAPIERROR_ORDER_CLOSE_ACC_CONTRACT = 60026
TAPIERROR_ORDER_CLOSE_SYSTEM = 60027
TAPIERROR_ORDER_CLOSE_DAYS = 60028
TAPIERROR_ORDER_NOTRADE_RISK = 60029
TAPIERROR_ORDER_CLOSE_RISK = 60030
TAPIERROR_ORDERINSERT_POSITIONMAX = 60031
TAPIERROR_ORDERINSERT_ONCEMAX = 60032
TAPIERROR_ORDERINSERT_TRADEROUTE = 60033
TAPIERROR_ORDER_IN_MOD_PRICE_ERROR = 60034
TAPIERROR_ORDER_IN_GIVEUP_POS_MAX = 60035
TAIERROR_ORDER_ETF_POSITIONMAX = 60036
TAIERROR_ORDER_ETF_BUYPOSITIONMAX = 60037
TAIERROR_ORDER_ETF_BUYONEDAYPOSITIONMAX = 60038
TAIERROR_ORDERINSERT_NOTENOUGHSPOT = 60039
TAIERROR_ORDERINSERT_RESERVE_SPOT = 60040
TAPIERROR_UPPERCHANNEL_NOT_LOGIN = 60041
TAPIERROR_UPPERCHANNEL_NOT_FOUND = 60042
TAPIERROR_COMMODITY_LOCK = 60043
TAPIERROR_SPOT_ROOT_COMMODITY = 60044
TAIERROR_SPOT_ROOTCOM_TRADEROUTE = 60045
TAPIERROR_ORDERINSERT_NOTENOUGHFUND = 60051
TAPIERROR_ORDERINSERT_FEE = 60052
TAPIERROR_ORDERINSERT_MARGIN = 60053
TAPIERROR_ORDERINSERT_BASENOFUND = 60054
TAPIERROR_ORDERINSERT_MARGINAMOUNT = 60055
TAPIERROR_ORDERINSERT_OPENRATIO = 60056
TAPIERROR_ORDERINSERT_GROUP_OPENRATIO = 60057
TAPIERROR_ORDERINSERT_RISKARRAY = 60058
TAIERROR_ORDERINSERT_BUYLIMITE = 60059
TAIERROR_ORDERINSERT_GROUP_BUYLIMITE = 60060
TAPIERROR_ORDERDELETE_NOT_SYSNO = 60061
TAPIERROR_ORDERDELETE_NOT_STATE = 60062
TAPIERROR_ORDERDELETE_NO_INPUT = 60063
TAPIERROR_ORDERDELETE_NO_TRADE = 60064
TAPIERROR_ORDERMODIFY_NOT_STATE = 60071
TAPIERROR_ORDERMODIFY_BACK_INPUT = 60072
TAPIERROR_ORDERMODIFY_RISK_ORDER = 60073
TAPIERROR_ORDERMODIFY_ERROR_QTY = 60074
TAPIERROR_ORDERMODIFY_ERROR_READY = 60075
TAPIERROR_ORDERINPUT_CANNOTMOVE = 60081
TAPIERROR_ORDERINPUT_REPEAT = 60091
TAPIERROR_CONTRACT_QUOTE = 60101
TAPIERROR_UPPER_ONCEMAX = 60111
TAPIERROR_UPPER_POSITIONMAX = 60112
TAPIERROR_ORDERINSERT_POSMAX_COM = 60113
TAPIERROR_ORDERINSERT_POSMAX_COM_NET = 60114
TAPIERROR_ORDERINSERT_CLOSEMODE = 60121
TAPIERROR_CLOSE_ORDER = 60122
TAPIERROR_CLOSE_MATCH = 60123
TAPIERROR_CLOSE_SPOT_OUT_LOCK = 60124
TAPIERROR_CLOSE_SPOT_OUT_NULL = 60125
TAPIERROR_MOD_DEL_NO_ORDER = 60131
TAPIERROR_MOD_DEL_GATEWAY_DISCON = 60132
TAPIERROR_MATCHINPUT_REPEAT = 60141
TAPIERROR_MATCHINPUT_NO_ORDER = 60142
TAPIERROR_MATCHINPUT_NO_CONTRACT = 60143
TAPIERROR_MATCHINPUT_PARM_ERROR = 60144
TAPIERROR_MATCHINPUT_OSTATE_ERROR = 60145
TAPIERROR_MATCHINPUT_OCMODE_ERROR = 60146
TAPIERROR_MATCHREMOVE_NO_MATCH = 60151
TAPIERROR_MATCHREMOVE_STATE_ERROR = 60152
TAPIERROR_MATCHINFO_CONTRACT_ERROR = 60153
TAPIERROR_ORDERINPUT_STATE_ERROR = 60161
TAPIERROR_ORDERINPUT_MOD_ERROR = 60162
TAPIERROR_ORDERREMOVE_ERROR = 60163
TAPIERROR_ORDERINPUT_MOD_STATE_ERROR = 60164
TAPIERROR_ORDEREXCHANGE_STATE_ERROR = 60165
TAPIERROR_ORDERREMOVE_NOT_ERROR = 60166
TAPIERROR_ORDERMARKET_DELETE_NOTFOUND = 60171
TAPIERROR_ORDERMARKET_DEL_ACCOUNT_NE = 60172
TAPIERROR_ORDERMARKET_DEL_COMMODITY_NE = 60173
TAPIERROR_ORDERMARKET_DEL_CONTRACT_NE = 60174
TAPIERROR_ORDERMARKET_DEL_SIDE_EQ = 60175
TAPIERROR_ORDERMARKET_DEL_SIDE_ERROR = 60176
TAPIERROR_ORDERMARKET_OTHER_SIDE_ERROR = 60177
TAPIERROR_ORDERMARKET_DEL_SYSTEMNO_ERROR = 60178
TAPIERROR_ORDERACTIVATE_NOTFOUND_ERROR = 60181
TAPIERROR_ORDERACTIVATE_STATE_ERROR = 60182
TAPIERROR_ORDERACTIVATE_GATEWAY_ERROR = 60183
TAPIERROR_TRANSIT_ORDERINSERT_RIGHT = 60191
TAPIERROR_TRANSIT_ORDERINSERT_DISCON = 60192
TAPIERROR_TRANSIT_ORDERINSERT_DISCON_DEST = 60193
TAPIERROR_TRANSIT_ORDERDELETE_DISCON_DEST = 60194
TAPIERROR_TRANSIT_ORDERMODIFY_DISCON_DEST = 60195
TAPIERROR_TRANSIT_ORDER_OPERATOR = 60196
TAPIERROR_ORDER_DISALLOWBUY_ACCOUNT = 60201
TAPIERROR_ORDER_DISALLOWSELL_ACCOUNT = 60202
TAPIERROR_ORDER_DISALLOWBUY_SYSTEM = 60203
TAPIERROR_ORDER_DISALLOWSELL_SYSTEM = 60204
TAPIERROR_ORDER_DIS_SELLOPTION_ACCOUNT = 60205
TAPIERROR_ORDER_DIS_SELLOPTION_SYSTEM = 60206
TAPIERROR_ORDER_CONTRACT_CLOSE = 60207
TAPIERROR_ORDER_INSERT_RISK_CLOSE = 60208
TAPIERROR_ORDERINSERT_LOANAMOUNT = 60211
TAPIERROR_COMBINE_COMMODITY = 60220
TAPIERROR_COMBINE_CALLORPUT = 60221
TAPIERROR_COMBINE_COMPOSITION = 60222
TAPIERROR_COMBINE_COMPOSITION_QTY = 60223
TAPIERROR_COMBINE_HEDGEFLAG = 60224
TAPIERROR_COMBINE_ORDERSIDE = 60225
TAPIERROR_COMBINE_CONTRACTSIZE = 60226
TAPIERROR_COMBINE_CONTRACTDAYS = 60227
TAPIERROR_COMBINE_STRIKEPRICE = 60228
TAPIERROR_COMBINE_CONTRACT_SAME = 60229
TAPIERROR_ORDERINSERT_UNLOCK_NOE = 60230
TAPIERROR_ORDEROPEN_OPT_SPOT_NOE = 60231
TAPIERROR_ORDERCLOSE_OPT_SPOT_NOE = 60232
TAPIERROR_ORDERINSERT_COVERED_UNVLD = 60233
TAPIERROR_ORDERINSERT_QUOTE_PRICE = 60240
TAPIERROR_ACCOUNTIPO_REPEAT = 60250
TAPIERROR_ACCOUNTIPO_NOT_EXIST = 60251
TAPIERROR_ORDERINSERT_MAIN_MARGIN = 60261
TAPIERROR_GW_NOT_READY = 80001
TAPIERROR_GW_INVALID_COMMODITY = 80002
TAPIERROR_GW_INVALID_CONTRACT = 80003
TAPIERROR_GW_INVALID_FIELD = 80004
TAPIERROR_GW_INVALID_PRICE = 80005
TAPIERROR_GW_INVALID_VOLUME = 80006
TAPIERROR_GW_INVALID_TYPE = 80007
TAPIERROR_GW_INVALID_MODE = 80008
TAPIERROR_GW_ORDER_NOT_EXIST = 80009
TAPIERROR_GW_SEND_FAIL = 80010
TAPIERROR_GW_REJ_BYUPPER = 80011
TAPIERROR_TRADEFRONT_MODULETYPEERR = 90001
TAPIERROR_TRADEFRONT_TOOMANYDATA = 90002
TAPIERROR_TRADEFRONT_NODATA = 90003
TAPIERROT_TRADEFRONT_NOUSER = 90004
TAPIERROR_TRADEFRONT_DISCONNECT_TRADE = 90011
TAPIERROR_TRADEFRONT_DISCONNECT_MANAGE = 90012
TAPIERROR_TRADEFRONT_ACCOUNT = 90021
TAPIERROR_TRADEFRONT_ORDER = 90022
TAPIERROR_TRADEFRONT_FREQUENCY = 90023
TAPIERROR_TRADEFRONT_RUFUSE = 90024
TAPIERROR_TRADEFRONT_SELFMATCH = 90025
TAPIERROR_TRADEFRONT_DELETEFORCE = 90026
TAPIERROR_SUCCEED = 0
TAPIERROR_ConnectFail = -1
TAPIERROR_LinkAuthFail = -2
TAPIERROR_HostUnavailable = -3
TAPIERROR_SendDataError = -4
TAPIERROR_TestIDError = -5
TAPIERROR_NotReadyTestNetwork = -6
TAPIERROR_CurTestNotOver = -7
TAPIERROR_NOFrontAvailable = -8
TAPIERROR_DataPathAvaiable = -9
TAPIERROR_RepeatLogin = -10
TAPIERROR_InnerError = -11
TAPIERROR_LastReqNotFinish = -12
TAPIERROR_InputValueError = -13
TAPIERROR_AuthCode_Invalid = -14
TAPIERROR_AuthCode_Expired = -15
TAPIERROR_AuthCode_TypeNotMatch = -16
TAPIERROR_API_NotReady = -17
TAPIERROR_UDP_LISTEN_FAILED = -18
TAPIERROR_UDP_LISTENING = -19
TAPIERROR_NotImplemented = -20
TAPIERROR_CallOneTimeOnly = -21
TAPIERROR_ORDER_FREQUENCY = -22
TAPIERROR_RENTQRY_TOOFAST = -23
TAPIERROR_CALL_NOCONDITION = -24
TAPIERROR_ORDER_NOTFOUND = -25
TAPIERROR_LOGPATH_EMPTY = -26
TAPIERROR_LOGPATH_FAILOPEN = -27
TAPIERROR_RIGHT_TRADER = -28
TAPIERROR_RIGHT_ORDERINPUT = -29
TAPIERROR_RIGHT_LOCALOPERATION = -30
TAPIERROR_RIGHT_ORDERTRANSFER = -31
TAPIERROR_FILLINPUT_SYSTEMNO = -32
TAPIERROR_FILLREMOVE_MATCHNO = -33
TAPIERROR_FILLREQMOVE_NOFUND = -34
TAPIERROR_LOCALMODIFY_ACCOUNT = -35
TAPIERROR_LOCALTRANSFER_ACCOUNT = -36
TAPIERROR_INPUTERROR_PHONE = -37
TAPIERROR_ERROR_CONTACT = -38
TAPIERROR_ERROR_REJESTVERTIFICATE = -39
TAPIERROR_ERROR_NOTREQUESTSECONDCODE = -44
TAPIERROR_RIGHT_SETPASSWORD = -40
TAPIERROR_RISK_OPERERROR = -41
TAPIERROR_ORDER_MODACCOUNT = -42
TAPIERROR_MEMORY_ALLOCFAILED = -43
TAPIERROR_ERROR_LICENSECOMMODITY = -45
TAPIERROR_ERROR_SYSTEMTYPE = -56
TAPIERROR_ERROR_RECONNECTING = -57
TAPIERROR_UNFREEZE_SUCCESS = -58
TAPIERROR_HISDATA_DAYS = -59
TAPIERROR_GATHERINFO_NORELAY = -46
TAPIERROR_GATHERINFO_PARTY = -47
TAPIERROR_GATHERINFO_DATALOAD = -48
TAPIERROR_ERROR_PRICETICK = -50
TAPIERROR_OVER_MAXLOANRATIO = -52
TAPIERROR_OVER_MAXLOANVALUE = -53
TAPIERROR_OVER_APPLYQTY = -54
TAPIERROR_NULL_IPOINFO = -55
TAPIERROR_INPUTERROR_NULL = -10000
TAPIERROR_INPUTERROR_TAPIYNFLAG = -10001
TAPIERROR_INPUTERROR_TAPILOGLEVEL = -10002
TAPIERROR_INPUTERROR_TAPICommodityType = -10003
TAPIERROR_INPUTERROR_TAPICallOrPutFlagType = -10004
TAPIERROR_INPUTERROR_TAPIBucketDateFlag = -11001
TAPIERROR_INPUTERROR_TAPIHisQuoteType = -11002
TAPIERROR_INPUTERROR_TAPIAccountType = -12001
TAPIERROR_INPUTERROR_TAPIUserTypeType = -12002
TAPIERROR_INPUTERROR_TAPIAccountState = -12003
TAPIERROR_INPUTERROR_TAPIAccountFamilyType = -12004
TAPIERROR_INPUTERROR_TAPIOrderTypeType = -12005
TAPIERROR_INPUTERROR_TAPIOrderSourceType = -12006
TAPIERROR_INPUTERROR_TAPITimeInForceType = -12007
TAPIERROR_INPUTERROR_TAPISideType = -12008
TAPIERROR_INPUTERROR_TAPIPositionEffectType = -12009
TAPIERROR_INPUTERROR_TAPIHedgeFlagType = -12010
TAPIERROR_INPUTERROR_TAPIOrderStateType = -12011
TAPIERROR_INPUTERROR_TAPICalculateModeType = -12012
TAPIERROR_INPUTERROR_TAPIMatchSourceType = -12013
TAPIERROR_INPUTERROR_TAPIOpenCloseModeType = -12014
TAPIERROR_INPUTERROR_TAPIFutureAlgType = -12015
TAPIERROR_INPUTERROR_TAPIOptionAlgType = -12016
TAPIERROR_INPUTERROR_TAPIBankAccountLWFlagType = -12017
TAPIERROR_INPUTERROR_TAPIBankAccountStateType = -12018
TAPIERROR_INPUTERROR_TAPIBankAccountSwapStateType = -12019
TAPIERROR_INPUTERROR_TAPIBankAccountTransferStateType = -12020
TAPIERROR_INPUTERROR_TAPIMarginCalculateModeType = -12021
TAPIERROR_INPUTERROR_TAPIOptionMarginCalculateModeType = -12022
TAPIERROR_INPUTERROR_TAPICmbDirectType = -12023
TAPIERROR_INPUTERROR_TAPIDeliveryModeType = -12024
TAPIERROR_INPUTERROR_TAPIContractTypeType = -12025
TAPIERROR_INPUTERROR_TAPIPartyTypeType = -12026
TAPIERROR_INPUTERROR_TAPIPartyCertificateTypeType = -12027
TAPIERROR_INPUTERROR_TAPIMsgReceiverType = -12028
TAPIERROR_INPUTERROR_TAPIMsgTypeType = -12029
TAPIERROR_INPUTERROR_TAPIMsgLevelType = -12030
TAPIERROR_INPUTERROR_TAPITransferDirectType = -12031
TAPIERROR_INPUTERROR_TAPITransferStateType = -12032
TAPIERROR_INPUTERROR_TAPITransferTypeType = -12033
TAPIERROR_INPUTERROR_TAPITransferDeviceIDType = -12034
TAPIERROR_INPUTERROR_TAPITacticsTypeType = -12035
TAPIERROR_INPUTERROR_TAPIORDERACT = -12036
TAPIERROR_INPUTERROR_TAPIBillTypeType = -12037
TAPIERROR_INPUTERROR_TAPIBillFileTypeType = -12038
TAPIERROR_INPUTERROR_TAPIOFFFlagType = -12039
TAPIERROR_INPUTERROR_TAPICashAdjustTypeType = -12040
TAPIERROR_INPUTERROR_TAPITriggerConditionType = -12041
TAPIERROR_INPUTERROR_TAPITriggerPriceTypeType = -12042
TAPIERROR_INPUTERROR_TAPITradingStateType = -12043
TAPIERROR_INPUTERROR_TAPIMarketLevelType = -12044
TAPIERROR_INPUTERROR_TAPIOrderQryTypeType = -12045
TAPIERROR_INPUTERROR_TAPIClientID = -12046
TAPIERROR_INPUTERROR_QryHisQuoteParam = -13001
TAPIERROR_INPUTERROR_TAPIIncludeNAN = -13002
TAPIERROR_INPUTERROR_TAPIPasswordType = -12048
TAPIERROR_INPUTERROR_TAPISettleFlagType = -12049
TAPIERROR_INPUTERROR_TAPILoginTypeType = -12050
TAPIERROR_INPUTERROR_TapAPISpecialOrderTypeType = -12051
TAPIERROR_INPUTERROR_TapAPICombineStrategyType = -12052
TAPIERROR_INPUTERROR_TAPIClientIDType = -12053
TAPIERROR_INPUTERROR_TAPIClientLocationIDType = -12054
TAPIERROR_INPUTERROR_TapAPIApplyTypeType = -12055
TAPIERROR_INPUTERROR_TAPIDATE = -12056
TAPIERROR_DISCONNECT_CLOSE_INIT = 1
TAPIERROR_DISCONNECT_CLOSE_PASS = 2
TAPIERROR_DISCONNECT_READ_ERROR = 3
TAPIERROR_DISCONNECT_WRITE_ERROR = 4
TAPIERROR_DISCONNECT_BUF_FULL = 5
TAPIERROR_DISCONNECT_IOCP_ERROR = 6
TAPIERROR_DISCONNECT_PARSE_ERROR = 7
TAPIERROR_DISCONNECT_CONNECT_TIMEOUT = 8
TAPIERROR_DISCONNECT_INIT_ERROR = 9
TAPIERROR_DISCONNECT_HAS_CONNECTED = 10
TAPIERROR_DISCONNECT_HAS_EXIT = 11
TAPIERROR_DISCONNECT_TRY_LATER = 12
