int qryTradingDate();

int qryAccount(const dict &data);

int qryFund(const dict &data);

int qryExchange();

int qryCommodity();

int qryContract(const dict &data);

int qryOrder(const dict &data);

int qryOrderProcess(const dict &data);

int qryFill(const dict &data);

int qryPosition(const dict &data);

int qryPositionSummary(const dict &data);

int qryCurrency();

int qryAccountCashAdjust(const dict &data);

int qryTradeMessage(const dict &data);

int qryBill(const dict &data);

int qryHisOrder(const dict &data);

int qryHisOrderProcess(const dict &data);

int qryHisMatch(const dict &data);

int qryHisPosition(const dict &data);

int qryHisDelivery(const dict &data);

int qryAccountFeeRent(const dict &data);

int qryAccountMarginRent(const dict &data);

